==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property appImageConfigName The name of the App Image Config.
 * @property imageName The name of the Custom Image.
 * @property imageVersionNumber The version number of the Custom Image.
 */
public data class UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs(
    public val appImageConfigName: Output<String>,
    public val imageName: Output<String>,
    public val imageVersionNumber: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs> {
    override fun toJava():
        com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs =
        com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs.builder()
            .appImageConfigName(appImageConfigName.applyValue({ args0 -> args0 }))
            .imageName(imageName.applyValue({ args0 -> args0 }))
            .imageVersionNumber(imageVersionNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs].
 */
@PulumiTagMarker
public class UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgsBuilder internal
constructor() {
    private var appImageConfigName: Output<String>? = null

    private var imageName: Output<String>? = null

    private var imageVersionNumber: Output<Int>? = null

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("tftvuogjaxpqjkuo")
    public suspend fun appImageConfigName(`value`: Output<String>) {
        this.appImageConfigName = value
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("cwvlydjhrrernonk")
    public suspend fun imageName(`value`: Output<String>) {
        this.imageName = value
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("obnfhpaluepfulna")
    public suspend fun imageVersionNumber(`value`: Output<Int>) {
        this.imageVersionNumber = value
    }

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("treebpenvvycieiy")
    public suspend fun appImageConfigName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.appImageConfigName = mapped
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("bdnveoloqkwtsmkw")
    public suspend fun imageName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.imageName = mapped
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("muqabafdjfwdsnjt")
    public suspend fun imageVersionNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageVersionNumber = mapped
    }

    internal fun build(): UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs =
        UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs(
            appImageConfigName = appImageConfigName ?: throw PulumiNullFieldException("appImageConfigName"),
            imageName = imageName ?: throw PulumiNullFieldException("imageName"),
            imageVersionNumber = imageVersionNumber,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property appImageConfigName The name of the App Image Config.
 * @property imageName The name of the Custom Image.
 * @property imageVersionNumber The version number of the Custom Image.
 */
public data class UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs(
    public val appImageConfigName: Output<String>,
    public val imageName: Output<String>,
    public val imageVersionNumber: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs> {
    override fun toJava(): com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs =
        com.pulumi.aws.sagemaker.inputs.UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs.builder()
            .appImageConfigName(appImageConfigName.applyValue({ args0 -> args0 }))
            .imageName(imageName.applyValue({ args0 -> args0 }))
            .imageVersionNumber(imageVersionNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs].
 */
@PulumiTagMarker
public class UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgsBuilder internal constructor() {
    private var appImageConfigName: Output<String>? = null

    private var imageName: Output<String>? = null

    private var imageVersionNumber: Output<Int>? = null

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("gaifjknvmjbkewjh")
    public suspend fun appImageConfigName(`value`: Output<String>) {
        this.appImageConfigName = value
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("xnycjhxqyfblfsgj")
    public suspend fun imageName(`value`: Output<String>) {
        this.imageName = value
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("taqihlqwlmkfkemm")
    public suspend fun imageVersionNumber(`value`: Output<Int>) {
        this.imageVersionNumber = value
    }

    /**
     * @param value The name of the App Image Config.
     */
    @JvmName("hxwjlxjihdopalft")
    public suspend fun appImageConfigName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.appImageConfigName = mapped
    }

    /**
     * @param value The name of the Custom Image.
     */
    @JvmName("wtcqaslpeltpppsp")
    public suspend fun imageName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.imageName = mapped
    }

    /**
     * @param value The version number of the Custom Image.
     */
    @JvmName("efxumekegsrwanpl")
    public suspend fun imageVersionNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageVersionNumber = mapped
    }

    internal fun build(): UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs =
        UserProfileUserSettingsKernelGatewayAppSettingsCustomImageArgs(
            appImageConfigName = appImageConfigName ?: throw PulumiNullFieldException("appImageConfigName"),
            imageName = imageName ?: throw PulumiNullFieldException("imageName"),
            imageVersionNumber = imageVersionNumber,
        )
}
